#!/usr/bin/env python

from django.conf import settings
from django.core.exceptions import ImproperlyConfigured
from django import forms
from django.forms.widgets import Input



class TinyColorPickerWidget(Input):
	input_type = 'text'
	template_name = 'tinycolorpicker/widget.html'

	def __init__(self, attrs=None, image=None, variant=None):
		super(TinyColorPickerWidget, self).__init__(attrs=attrs)
		self.image = image or getattr(settings, 'TINYCOLORPICKER_IMAGE', 'tinycolorpicker/img/text-color.png')
		self.variant = variant or getattr(settings, 'TINYCOLORPICKER_VARIANT', 'vanilla')


	def get_context(self, name, value, attrs):
		context = super(TinyColorPickerWidget, self).get_context(name, value, attrs)
		context['widget']['image'] = self.image
		context['widget']['variant'] = self.variant
		return context


	@property
	def media(self):
		if self.variant == 'vanilla':
			if settings.DEBUG:
				js = ['tinycolorpicker/js/tinycolorpicker.js',]
			else:
				js = ['tinycolorpicker/js/tinycolorpicker.min.js',]
		elif self.variant == 'jquery':
			if settings.DEBUG:
				js = ['tinycolorpicker/js/jquery.tinycolorpicker.js',]
			else:
				js = ['tinycolorpicker/js/jquery.tinycolorpicker.min.js',]
		else:
			raise ImproperlyConfigured("TINYCOLORPICKER_VARIANT must be one of 'vanilla' or 'jquery'")

		css = ['tinycolorpicker/css/tinycolorpicker.css',]
		return forms.Media(css={'all': css}, js=js)



#!/usr/bin/env python

import re

from django.core.validators import RegexValidator
from django.forms.fields import Field
from django.utils.translation import ugettext_lazy as _

from widgets import TinyColorPickerWidget


# Validation for hex colors
COLOR_REGEX = re.compile('^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$')
COLOR_VALIDATOR = RegexValidator(COLOR_REGEX, _('Enter a valid color.'), 'invalid')



class TinyColorPickerField(Field):
	widget = TinyColorPickerWidget
	default_validators = [COLOR_VALIDATOR,]



#! /usr/bin/env python
from setuptools import find_packages, setup

version = '0.1.0'

setup(
	name='django-tinycolorpicker',
	packages=find_packages(),
	include_package_data=True,
	version=version,
	license='MIT',
	url='https://www.github.com/perdixsw/django-tinycolorpicker',
	download_url='https://www.github.com/perdixsw/django-tinycolorpicker/archive/%s.tar.gz' % version,
	author='Perdix Software',
	author_email='ssmith@perdixsw.com',
	description='Django Field and Widget implementation of wieringen/tinycolorpicker',
	long_description='Django Field and Widget implementation of wieringen/tinycolorpicker',
	keywords=['django', 'color', 'field', 'colorpicker', 'tinycolorpicker',],
	zip_safe=False,
	classifiers=[
		'Development Status :: 4 - Beta',
		'Intended Audience :: Developers',
		'License :: OSI Approved :: MIT License',
		'Operating System :: OS Independent',
		'Programming Language :: Python',
		'Programming Language :: Python :: 2.7',
		'Programming Language :: Python :: 3',
		'Programming Language :: Python :: 3.4',
		'Programming Language :: Python :: 3.5',
		'Programming Language :: Python :: 3.6',
	],
)
